@@ -5,7 +5,7 @@ use Mouse::Role;
 
 # ABSTRACT: Web::API - A Simple base module to implement almost every RESTful API with just a few lines of configuration
 
-our $VERSION = '1.2'; # VERSION
+our $VERSION = '1.3'; # VERSION
 
 use LWP::UserAgent;
 use HTTP::Cookies;
@@ -236,7 +236,7 @@ sub nonce {
 }
 
 
-sub log { ## no critic (ProhibitBuiltinHomonyms)
+sub log {    ## no critic (ProhibitBuiltinHomonyms)
     my ($self, $msg) = @_;
     print STDERR __PACKAGE__ . ': ' . $msg . $/;
     return;
@@ -369,17 +369,24 @@ sub talk {
 
     $uri = $oauth_req->to_url if ($self->auth_type eq 'oauth_params');
 
+    # build headers
+    my %header;
+    if (exists $command->{headers} and ref $command->{headers} eq 'HASH') {
+        %header = (%{ $self->header }, %{ $command->{headers} });
+    }
+    else {
+        %header = %{ $self->header };
+    }
+    my $headers = HTTP::Headers->new(%header, "Accept" => $content_type->{in});
+
     if ($self->debug) {
         $self->log("uri: $method $uri");
-        $self->log("extra header:\n" . dump($self->header))
-            if (%{ $self->header });
-        $self->log("OAuth header: " . $oauth_req->to_authorization_header)
+        $self->log("extra headers:\n" . dump(\%header)) if (%header);
+        $self->log("OAuth headers:\n" . $oauth_req->to_authorization_header)
             if ($self->auth_type eq 'oauth_header');
     }
 
-    # build headers/request
-    my $headers =
-        HTTP::Headers->new(%{ $self->header }, "Accept" => $content_type->{in});
+    # build request
     my $request = HTTP::Request->new($method, $uri, $headers);
     unless ($method =~ m/^(GET|HEAD|DELETE)$/) {
         $request->header("Content-type" => $content_type->{out});
@@ -607,7 +614,7 @@ Web::API - Web::API - A Simple base module to implement almost every RESTful API
 
 =head1 VERSION
 
-version 1.2
+version 1.3
 
 =head1 SYNOPSIS
 
